@@ -3,10 +3,14 @@ import CoreML
 
 
 class TestMLModelConfiguration(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(CoreML.MLComputeUnits)
+
     def test_constants(self):
         self.assertEqual(CoreML.MLComputeUnitsCPUOnly, 0)
         self.assertEqual(CoreML.MLComputeUnitsCPUAndGPU, 1)
         self.assertEqual(CoreML.MLComputeUnitsAll, 2)
+        self.assertEqual(CoreML.MLComputeUnitsCPUAndNeuralEngine, 3)
 
     @min_os_level("10.15")
     def test_methods10_15(self):
