@@ -3,6 +3,9 @@ import CoreML
 
 
 class TestMLTask(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(CoreML.MLTaskState)
+
     def test_constants(self):
         self.assertEqual(CoreML.MLTaskStateSuspended, 1)
         self.assertEqual(CoreML.MLTaskStateRunning, 2)
